import numpy as np
import scipy.integrate as integrate

def func_f( u, t, z, alpha, gamma ):
	cs = np.cos( t )
	dn = u**2 + alpha**2 - 2.0 * alpha * u * cs
	dn1 = dn + ( z + gamma / 2.0 )**2
	dn2 = dn + ( z - gamma / 2.0 )**2 
	return u * ( alpha - u * cs ) * ( 1.0 / dn1**(1.5) - 1.0 / dn2**(1.5) )

def func_g2( z, alpha, gamma ):
	integral_r_t = integrate.dblquad( func_f, 0, np.pi, lambda x: 0, lambda x: 1, args=( z, alpha, gamma, ))[ 0 ]
	return integral_r_t**2

N_alpha = 70
N_gamma = 300
F = np.zeros( ( N_alpha * N_gamma, 3 ), dtype = np.float64 )
d_alpha = 0.7 / N_alpha
d_gamma = 3.0 / N_gamma
for i in range( N_alpha ):
	for j in range( N_gamma ):
		index = i * N_gamma + j
		F[ index, 0 ] = 0.01 + d_alpha * i   #alpha = a / b
		F[ index, 1 ] = 0.01 + d_gamma * j    #gamma = d / b
S=np.copy( F )


for i in range( N_alpha ):
	for j in range( N_gamma ):
		print (i, j)
		index = i * N_gamma + j
		F[ index, 2 ] =integrate.quad(func_g2, -np.inf, np.inf, args=(F[ index, 0 ], F[ index, 1 ] ))[ 0 ]
		S[ index, 2 ] = ( 45 * ( np.pi )**3 / 512 ) * (F[ index, 0 ])**2 * (F[ index, 1 ])**2 / F[ index, 2 ]

np.savetxt("S.csv", S, delimiter=','  )
